@@ -190,7 +190,7 @@ pub struct SlackApiChatGetPermalinkRequest {
 #[derive(Debug, PartialEq, Clone, Serialize, Deserialize, Builder)]
 pub struct SlackApiChatGetPermalinkResponse {
     pub channel: SlackChannelId,
-    pub message_ts: SlackTs,
+    pub permalink: String,
 }
 
 #[skip_serializing_none]
@@ -360,8 +360,7 @@ impl SlackApiScrollableResponse for SlackApiChatScheduledMessagesListResponse {
     fn next_cursor(&self) -> Option<&Self::CursorType> {
         self.response_metadata
             .as_ref()
-            .map(|rm| rm.next_cursor.as_ref())
-            .flatten()
+            .and_then(|rm| rm.next_cursor.as_ref())
     }
 
     fn scrollable_items<'a>(&'a self) -> Box<dyn Iterator<Item = &'a Self::ResponseItemType> + 'a> {
