@@ -235,8 +235,7 @@ impl SlackApiScrollableResponse for SlackApiUsersConversationsResponse {
     fn next_cursor(&self) -> Option<&Self::CursorType> {
         self.response_metadata
             .as_ref()
-            .map(|rm| rm.next_cursor.as_ref())
-            .flatten()
+            .and_then(|rm| rm.next_cursor.as_ref())
     }
 
     fn scrollable_items<'a>(&'a self) -> Box<dyn Iterator<Item = &'a Self::ResponseItemType> + 'a> {
@@ -286,8 +285,7 @@ impl SlackApiScrollableResponse for SlackApiUsersListResponse {
     fn next_cursor(&self) -> Option<&Self::CursorType> {
         self.response_metadata
             .as_ref()
-            .map(|rm| rm.next_cursor.as_ref())
-            .flatten()
+            .and_then(|rm| rm.next_cursor.as_ref())
     }
 
     fn scrollable_items<'a>(&'a self) -> Box<dyn Iterator<Item = &'a Self::ResponseItemType> + 'a> {
